#!/bin/sh

# ******************************************************************
# *                                                                *
# *       DVBTENCO - An ETSI DVB-T standard encoder/modulator.     *
# *                                                                *
# *    This encoder/modulator follows the specifications of the    *
# *    standard ETSI EN 300 744 V1.1.2 (1997-08).                  *
# *                                                                *
# *    Author: Giuseppe Baruffa (baruffa@diei.unipg.it)            *
# *                                                                *
# *                   Copyright 2000-2004                          *
# *                                                                *
# ******************************************************************

#	Batch test file for the dvbtenco program

# Setting variables

ENCO=./dvbtenco
TESTFILE=test.m2v
MP2GEN=./mpeg2gen
TSTLEN=1200000
SPEEDFILE=test_unix.txt
TEMPFILE=temporary_dvbtenco_file.txt
CHECKWPP=./wppcheck
CLOCKMHZ=400

MODES="2k 8k"
CONST="4 16 64"
ALPHA="NH 1 2 4"
DELTA="1/32 1/16 1/8 1/4"
RATES="1/2 2/3 3/4 5/6 7/8"

echo 
echo Speed test for $ENCO
echo

if [ ! -f $TESTFILE ] ; then 
	echo Creating test file
	$MP2GEN $TSTLEN $TESTFILE ;
fi

if [ -f $SPEEDFILE ] ; then rm $SPEEDFILE ; fi

for m in $MODES ; do
	for M in $CONST ; do
		for a in $ALPHA ; do
			for d in $DELTA ; do
				for r in $RATES ; do 
					echo $m $M $a $d $r
					$ENCO -i $TESTFILE -$m -M $M -a $a -D $d -p $r -v 1 > $TEMPFILE
					cat $TEMPFILE
					cat $TEMPFILE >> $SPEEDFILE
				done ;
			done ;
		done ;
	done ;
done

if [ -f $TEMPFILE ] ; then rm $TEMPFILE ; fi

echo Test done

$CHECKWPP $SPEEDFILE $CLOCKMHZ

